==> haskell-primitive-extras-0.10.2.2-100-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive-extras
version:              0.10.2.2
visibility:           public
id:                   primitive-extras-0.10.2.2-GbKBQNzruP9J0tPKwFgcxN
key:                  primitive-extras-0.10.2.2-GbKBQNzruP9J0tPKwFgcxN
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/primitive-extras
synopsis:             Extras for the "primitive" library
description:
    Raw collection of extra utiltilies for the "primitive" library.

category:             Primitive
abi:                  8c5749deebb6823644f31b79f5e1e511
exposed:              True
exposed-modules:
    PrimitiveExtras.Bitmap PrimitiveExtras.By6Bits
    PrimitiveExtras.PrimArray PrimitiveExtras.PrimMultiArray
    PrimitiveExtras.SmallArray PrimitiveExtras.UnliftedArray

hidden-modules:
    PrimitiveExtras.FoldMs PrimitiveExtras.Folds
    PrimitiveExtras.Prelude PrimitiveExtras.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/primitive-extras-0.10.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/primitive-extras-0.10.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/primitive-extras-0.10.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-extras
hs-libraries:         HSprimitive-extras-0.10.2.2-GbKBQNzruP9J0tPKwFgcxN
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    deferred-folds-0.9.18.7-BbZyewZaL4HD3b1RMnK7yy
    focus-1.0.3.2-DBDDXJ7IsLr9dtjYUov5u6
    foldl-1.4.18-IjeZVo98k0G8iToMFzzV6X
    list-t-1.0.5.7-EJ3gydpvNy7LFPsItC9ump
    primitive-0.9.1.0-6nUciex1vJZHfhyE758nym
    primitive-unlifted-2.2.0.0-8IKaBt8wSegHApEa4k62BQ
    profunctors-5.6.3-5ykNj0b49W3C5puCJKHDiE
    vector-0.13.2.0-B3Rnif6nhJNLHPAZlzHp2g

haddock-interfaces:
    /usr/share/doc/haskell-primitive-extras/html/primitive-extras.haddock

haddock-html:         /usr/share/doc/haskell-primitive-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primitive-extras-0.10.2.2-101-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive-extras
version:              0.10.2.2
visibility:           public
id:                   primitive-extras-0.10.2.2-24QMwRbTsO37mVpaoildYT
key:                  primitive-extras-0.10.2.2-24QMwRbTsO37mVpaoildYT
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/primitive-extras
synopsis:             Extras for the "primitive" library
description:
    Raw collection of extra utiltilies for the "primitive" library.

category:             Primitive
abi:                  1db3cc5dd3fbf5b58c739331dcb28be8
exposed:              True
exposed-modules:
    PrimitiveExtras.Bitmap PrimitiveExtras.By6Bits
    PrimitiveExtras.PrimArray PrimitiveExtras.PrimMultiArray
    PrimitiveExtras.SmallArray PrimitiveExtras.UnliftedArray

hidden-modules:
    PrimitiveExtras.FoldMs PrimitiveExtras.Folds
    PrimitiveExtras.Prelude PrimitiveExtras.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/primitive-extras-0.10.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/primitive-extras-0.10.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/primitive-extras-0.10.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-extras
hs-libraries:         HSprimitive-extras-0.10.2.2-24QMwRbTsO37mVpaoildYT
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    deferred-folds-0.9.18.7-EFYcLvCXaM37142kL32laC
    focus-1.0.3.2-A8LZIRiFaS44o7xKmeZpXy
    foldl-1.4.18-4P7zg2rzS1II56Ld8UKgdO
    list-t-1.0.5.7-GiyCsWRvIJnKJGy8VJpPo5
    primitive-0.9.1.0-D2h8cSAG2AjKP2pRuhtPBO
    primitive-unlifted-2.2.0.0-57aRUB6l52f2cI6VjGcGeL
    profunctors-5.6.3-KOZLO1xtOlQD6lxDMCq9YO
    vector-0.13.2.0-7UWGIXxclbLLOjGg0s2qXt

haddock-interfaces:
    /usr/share/doc/haskell-primitive-extras/html/primitive-extras.haddock

haddock-html:         /usr/share/doc/haskell-primitive-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
